@@ -4,7 +4,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2009,2010,2012 Slaven Rezic. All rights reserved.
+# Copyright (C) 2009,2010,2012,2013 Slaven Rezic. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -22,7 +22,7 @@ use CPAN::DistnameInfo ();
 {
     package Parse::CPAN::Packages::Fast;
 
-    our $VERSION = '0.05_53';
+    our $VERSION = '0.06_50';
     $VERSION =~ s{_}{};
 
     use PerlIO::gzip;
@@ -46,9 +46,11 @@ use CPAN::DistnameInfo ();
     sub _default_packages_file_batch {
 	my($class) = @_;
 
-	my $home_cpandir = "$ENV{HOME}/.cpan";
-	if (!$INC{"CPAN/MyConfig.pm"}) {
+	my $home_cpandir = do {
 	    no warnings 'uninitialized'; # HOME may be uninitialized on some systems e.g. Windows
+	    "$ENV{HOME}/.cpan";
+	};
+	if (!$INC{"CPAN/MyConfig.pm"}) {
 	    my $home_myconfig = "$home_cpandir/CPAN/MyConfig.pm";
 	    if (-r $home_myconfig) {
 		local @INC = ($home_cpandir);
@@ -56,7 +58,10 @@ use CPAN::DistnameInfo ();
 	    }
 	}
 	if ($INC{"CPAN/MyConfig.pm"} && $CPAN::Config->{keep_source_where}) {
-	    return $CPAN::Config->{keep_source_where} . "/modules/02packages.details.txt.gz";
+	    my $packages_file = $CPAN::Config->{keep_source_where} . "/modules/02packages.details.txt.gz";
+	    if (-r $packages_file && -s $packages_file) {
+		return $packages_file;
+	    }
 	}
 
 	# Cannot find a usable CPAN::MyConfig, try a default location
